import { BaseApiClient } from './base';
import { API_CONFIG } from '../config/api';
import type { CandidateAssets, CandidateDetails, CandidateRedesSociais, CandidateSearchResult, CpfRevealResult, PlatformStats } from './apiModels';

/**
 * OpenCand API client for interacting with the OpenCand platform
 */
export class OpenCandApi extends BaseApiClient {
  constructor(baseUrl: string = '') {
    super(baseUrl);
  }

  /**
   * Get platform statistics
   * GET /v1/stats
   */
  async getStats(): Promise<PlatformStats> {
    return this.get<PlatformStats>('/v1/stats');
  }

  /**
   * Search for candidates by name or other attributes
   */
  async searchCandidates(query: string): Promise<CandidateSearchResult> {
    const encodedQuery = encodeURIComponent(query);
    return this.get<CandidateSearchResult>(`/v1/candidato/search?q=${encodedQuery}`);
  }

  /**
   * Get detailed information about a specific candidate by ID
   */
  async getCandidateById(id: string): Promise<CandidateDetails> {
    return this.get<CandidateDetails>(`/v1/candidato/${id}`);
  }

  /**
   * Get the assets of a specific candidate by ID
   */
  async getCandidateAssets(id: string): Promise<CandidateAssets> {
    return this.get<CandidateAssets>(`/v1/candidato/${id}/bens`);
  }

  /**
   * Get the social networks of a specific candidate by ID
   */
  async getCandidateRedesSociais(id: string): Promise<CandidateRedesSociais> {
    return this.get<CandidateRedesSociais>(`/v1/candidato/${id}/rede-social`);
  }

  /**
   * Get the social networks of a specific candidate by ID
   */
  async getCandidateCpf(id: string): Promise<CpfRevealResult> {
    return this.get<CpfRevealResult>(`/v1/candidato/${id}/reveal-cpf`);
  }
}

// Create a default instance for easy usage with proper configuration
export const openCandApi = new OpenCandApi(API_CONFIG.baseUrl);

// Export the API error for error handling
export { ApiError } from './base';
