import React, { useState } from 'react';
import { UserIcon } from '@heroicons/react/24/outline';
import { type CandidateDetails, openCandApi } from '../../api';
import { formatCpf, maskCpf } from '../../utils/utils';

interface BasicCandidateInfoComponentProps {
  candidateDetails: CandidateDetails | null;
  isLoading: boolean;
}

const BasicCandidateInfoComponent: React.FC<BasicCandidateInfoComponentProps> = ({ 
  candidateDetails, 
  isLoading 
}) => {
  const [revealedCpf, setRevealedCpf] = useState<string | null>(null);
  const [isRevealingCpf, setIsRevealingCpf] = useState(false);

  const formatDate = (dateString: string) => {
    try {
      const date = new Date(dateString);
      return date.toLocaleDateString('pt-BR');
    } catch {
      return dateString;
    }
  };

  const handleCpfClick = async () => {
    if (!candidateDetails?.idCandidato || isRevealingCpf || revealedCpf) return;
    
    setIsRevealingCpf(true);
    try {
      const cpfResult = await openCandApi.getCandidateCpf(candidateDetails?.idCandidato || '');
      setRevealedCpf(formatCpf(cpfResult.cpf));
    } catch (error) {
      console.error('Failed to reveal CPF:', error);
    } finally {
      setIsRevealingCpf(false);
    }
  };

  return (
    <div className="bg-white/95 backdrop-blur-sm rounded-xl shadow-lg hover:shadow-xl transform hover:scale-[1.01] transition-all duration-200 p-6">
      <div className="flex items-center mb-6">
        <UserIcon className="h-8 w-8 text-blue-600 mr-3" />
        <h2 className="text-2xl font-bold text-gray-900">Informações Básicas</h2>
      </div>

      {isLoading ? (
        <div className="flex items-center justify-center h-64">
          <div className="animate-spin rounded-full h-12 w-12 border-4 border-blue-600 border-t-transparent"></div>
        </div>
      ) : candidateDetails ? (
        <div className="space-y-4">
          {/* Candidate Photo */}
          {candidateDetails.fotoUrl && (
            <div className="flex justify-center mb-6">
              <div className="relative">
                <img
                  src={candidateDetails.fotoUrl}
                  alt={`Foto de ${candidateDetails.nome}`}
                  className="w-32 h-32 rounded-full object-cover border-4 border-blue-200 shadow-lg"
                  onError={(e) => {
                    const target = e.target as HTMLImageElement;
                    target.style.display = 'none';
                  }}
                />
              </div>
            </div>
          )}

          <div>
            <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Nome</label>
            <p className="text-lg font-medium text-gray-900 mt-1">{candidateDetails.nome}</p>
          </div>
          
          {candidateDetails.cpf && 
            <div>
              <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">CPF</label>
              <div 
                className={`text-lg text-gray-900 mt-1 ${
                  !revealedCpf && !isRevealingCpf ? 'cursor-pointer hover:text-blue-600 transition-colors duration-200' : ''
                }`}
                onClick={handleCpfClick}
              >
                {isRevealingCpf ? (
                  <div className="flex items-center justify-center space-x-2 py-1">
                    <div className="animate-spin rounded-full h-4 w-4 border-2 border-blue-200 border-t-blue-600"></div>
                    <span className="animate-pulse text-blue-600">Carregando...</span>
                  </div>
                ) : (
                  <span className={revealedCpf ? '' : 'select-none'}>
                    {revealedCpf || maskCpf(candidateDetails.cpf)}
                  </span>
                )}
              </div>
            </div>
          }

          <div>
            <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Data de Nascimento</label>
            <p className="text-lg text-gray-900 mt-1">{formatDate(candidateDetails.dataNascimento)}</p>
          </div>

          {candidateDetails.email && (
            <div>
              <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Email</label>
              <p className="text-lg text-gray-900 mt-1">{candidateDetails.email}</p>
            </div>
          )}

          <div>
            <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Estado Civil</label>
            <p className="text-lg text-gray-900 mt-1">{candidateDetails.estadoCivil}</p>
          </div>

          <div>
            <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Sexo</label>
            <p className="text-lg text-gray-900 mt-1">{candidateDetails.sexo}</p>
          </div>

          <div>
            <label className="text-sm font-semibold text-gray-600 uppercase tracking-wide">Ocupação</label>
            <p className="text-lg text-gray-900 mt-1">{candidateDetails.ocupacao}</p>
          </div>
        </div>
      ) : (
        <div className="text-center text-gray-500 py-8">
          Nenhuma informação encontrada
        </div>
      )}
    </div>
  );
};

export default BasicCandidateInfoComponent;
